DROP VIEW V_IMPORT_LINKS
;

CREATE OR REPLACE VIEW V_IMPORT_LINKS AS 
SELECT I.*, 
(CASE 
WHEN I.TABLE_NAME IN ('SALDKONT','E_INVOICE') THEN S.OWNER 
WHEN I.TABLE_NAME='KUPCI' THEN RTRIM(K.PRIIMEK ||' ' || COALESCE(K.IME, ' ')) 
WHEN I.TABLE_NAME='PLOVILA' THEN RTRIM(KP.PRIIMEK ||' ' || COALESCE(KP.IME, ' ')) 
WHEN I.TABLE_NAME='EXCHANGE' THEN E.OWNER 
WHEN I.TABLE_NAME='S_DOKUMENT' THEN D.OWNER 
WHEN I.TABLE_NAME='M_POGODBE' THEN POG.OWNER 
ELSE NULL 
END) AS OWNER,
(CASE 
WHEN I.TABLE_NAME IN ('SALDKONT','E_INVOICE') THEN S.VESSEL 
WHEN I.TABLE_NAME='EXCHANGE' THEN E.VESSEL 
WHEN I.TABLE_NAME='PLOVILA' THEN P.IME 
WHEN I.TABLE_NAME='M_POGODBE' THEN POG.VESSEL 
ELSE NULL 
END) AS VESSEL
FROM IMPORT_LINKS I
LEFT OUTER JOIN 
(SELECT SS.ID_SALDKONT AS ID, RTRIM(SK.PRIIMEK ||' ' || COALESCE(SK.IME, ' ')) AS OWNER, SP.IME AS VESSEL
  FROM SALDKONT SS LEFT OUTER JOIN KUPCI SK ON SS.ID_KUPCA=SK.ID LEFT OUTER JOIN PLOVILA SP ON SS.ID_PLOVILA=SP.ID) S ON I.INT_ID=S.ID AND I.TABLE_NAME IN ('SALDKONT','E_INVOICE')
LEFT OUTER JOIN KUPCI K ON I.INT_ID=K.ID AND I.TABLE_NAME='KUPCI'
LEFT OUTER JOIN PLOVILA P ON I.INT_ID=P.ID AND I.TABLE_NAME='PLOVILA'
LEFT OUTER JOIN KUPCI KP ON P.ID_LASTNIKA=KP.ID AND I.TABLE_NAME='PLOVILA'
LEFT OUTER JOIN 
(SELECT EE.ID, RTRIM(EK.PRIIMEK ||' ' || COALESCE(EK.IME, ' ')) AS OWNER, EP.IME AS VESSEL
  FROM EXCHANGE EE LEFT OUTER JOIN SALDKONT ES ON EE.ID_SALDKONT=ES.ID_SALDKONT LEFT OUTER JOIN KUPCI EK ON ES.ID_KUPCA=EK.ID LEFT OUTER JOIN PLOVILA EP ON ES.ID_PLOVILA=EP.ID
) E ON I.INT_ID=E.ID AND I.TABLE_NAME='EXCHANGE'
LEFT OUTER JOIN 
(SELECT DD.ID_DOKUMENT AS ID, RTRIM(DK.PRIIMEK ||' ' || COALESCE(DK.IME, ' ')) AS OWNER
  FROM S_DOKUMENT DD LEFT OUTER JOIN KUPCI DK ON DD.DOBAVITELJ=DK.ID) D ON I.INT_ID=D.ID AND I.TABLE_NAME='S_DOKUMENT'
LEFT OUTER JOIN 
(SELECT MP.ID_POGODBE AS ID, RTRIM(MK.PRIIMEK ||' ' || COALESCE(MK.IME, ' ')) AS OWNER, MPL.IME AS VESSEL
  FROM M_POGODBE MP LEFT OUTER JOIN KUPCI MK ON MP.ID_LASTNIKA=MK.ID LEFT OUTER JOIN PLOVILA MPL ON MP.ID_PLOVILA=MPL.ID) POG ON I.INT_ID=POG.ID AND I.TABLE_NAME='M_POGODBE'
;

ALTER TABLE PAYMENT_TRANSACTION
ADD IMPORT_DATE DATE
;

UPDATE PAYMENT_TRANSACTION
SET IMPORT_DATE = TRANSACTION_DATE
WHERE IMPORT_DATE IS NULL
;

DROP VIEW V_PAYMENT_TRANSACTION 
;

CREATE OR REPLACE VIEW V_PAYMENT_TRANSACTION AS (
SELECT PT.ID, PT.ID_SALDKONT_INV, PT.ID_SALDKONT_PAY, PT.ID_LASTNIKA, PT.ACCOUNT_FROM, PT.ACCOUNT_TO, PT.AMOUNT, PT.CURRENCY_CODE, PT.TRANSACTION_DATE, PT.TRANSACTION_MESSAGE, PT.STATUS, 
PT.PAYMENT_NKNJIZBA, PT."COMMENT", PT.NNLOCATION_ID, PT.REFERENCE, PT.INVOICE_NUMBER, PT.NEW_INTERNAL_TRANSACTION, PT.PAYMENT_DATE, PT.ID_ACCOUNT, PT.STATEMENT_ACCOUNT,  PT.STATEMENT_NR, PT.IMPORT_DATE, 
(SELECT SUM(S.ZA_PLACILO) FROM SALDKONT S, PAYMENT_TRANSACTION_SALDKONT PTS WHERE S.ID_SALDKONT = PTS.ID_SALDKONT AND PTS.ID_PAYMENT_TRANSACTION = PT.ID) AS APPLIED_AMOUNT,
KU.IME AS KUPCI_IME, KU.PRIIMEK AS KUPCI_PRIIMEK, 
(CASE WHEN PT.ID_LASTNIKA IS NOT NULL THEN ((CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (KU.IME || ' ' || KU.PRIIMEK) ELSE (KU.PRIIMEK || ' ' || KU.IME) END)) ELSE NAME END) AS OWNER,
PKN.SLO AS PAYMENT_NKNJIZBA_OPIS, PKN.SALDKONT AS PAYMENT_NKNJIZBA_SALDKONT, SI.N_RACUNA AS SALDKONT_INVOICE_N_RACUNA, 
SI.ZA_PLACILO AS SALDKONT_INVOICE_ZA_PLACILO, SI.PORABLJENO AS SALDKONT_INVOICE_PORABLJENO, SP.N_RACUNA AS SALDKONT_PAYMENT_N_RACUNA,
SP.ZA_PLACILO AS SALDKONT_PAYMENT_ZA_PLACILO, SP.PORABLJENO AS SALDKONT_PAYMENT_PORABLJENO, PT.ID_CARDS
FROM PAYMENT_TRANSACTION PT
LEFT OUTER JOIN KUPCI KU ON KU.ID = PT.ID_LASTNIKA
LEFT OUTER JOIN NKNJIZBA PKN ON PKN.NKNJIZBA = PT.PAYMENT_NKNJIZBA
LEFT OUTER JOIN SALDKONT SI ON SI.ID_SALDKONT = PT.ID_SALDKONT_INV
LEFT OUTER JOIN SALDKONT SP ON SP.ID_SALDKONT = PT.ID_SALDKONT_PAY
)
;

CREATE OR REPLACE 
TRIGGER PAYMENT_TRANS_IMPORT_DATE
BEFORE INSERT OR UPDATE
ON PAYMENT_TRANSACTION
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
BEGIN
IF (:NEW.IMPORT_DATE IS NULL) THEN
:NEW.IMPORT_DATE := :NEW.TRANSACTION_DATE;;
END IF;;
END;;
;

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (2287, SYSDATE, '5.5', 2207, 'PAYMENT_TRANSACTION')
;
